var indexSectionsWithContent =
{
  0: "abcdfiklmoprstv",
  1: "r",
  2: "r",
  3: "r",
  4: "abm",
  5: "r",
  6: "r",
  7: "r",
  8: "r",
  9: "acdfiorstv",
  10: "alrst"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Modules",
  10: "Pages"
};

